==> cayenne-3.0.2-src.tar.gz: cayenne-3.0.2-src/framework/cayenne-jdk1.5-unpublished/src/test/java/org/apache/cayenne/dba/sqlserver/SQLServerSnifferTest.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.dba.sqlserver;

import java.sql.Connection;
import java.sql.SQLException;

import org.apache.cayenne.dba.DbAdapter;
import org.apache.cayenne.unit.AccessStackAdapter;
import org.apache.cayenne.unit.CayenneCase;
import org.apache.cayenne.unit.SQLServerStackAdapter;

public class SQLServerSnifferTest extends CayenneCase {

    public void testCreateAdapter() throws Exception {

        SQLServerSniffer sniffer = new SQLServerSniffer();

        DbAdapter adapter = null;
        Connection c = getConnection();

        try {
            adapter = sniffer.createAdapter(c.getMetaData());
        }
        finally {
            try {
                c.close();
            }
            catch (SQLException e) {

            }
        }

        // only test with SQLServer adapter
        AccessStackAdapter testAdapter = getAccessStackAdapter();
        boolean sqlServer = testAdapter instanceof SQLServerStackAdapter;

        if (sqlServer) {
            assertNotNull(adapter);
        }
        else {
            assertNull(adapter);
        }
    }
}

==> cayenne-3.1.3-src.tar.gz: cayenne-3.1.3-src/framework/cayenne-jdk1.5-unpublished/src/test/java/org/apache/cayenne/dba/sqlserver/SQLServerSnifferTest.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.dba.sqlserver;

import java.sql.Connection;
import java.sql.SQLException;

import org.apache.cayenne.dba.DbAdapter;
import org.apache.cayenne.di.AdhocObjectFactory;
import org.apache.cayenne.di.Inject;
import org.apache.cayenne.unit.UnitDbAdapter;
import org.apache.cayenne.unit.SQLServerUnitDbAdapter;
import org.apache.cayenne.unit.di.server.ServerCase;
import org.apache.cayenne.unit.di.server.ServerCaseDataSourceFactory;
import org.apache.cayenne.unit.di.server.UseServerRuntime;

@UseServerRuntime(ServerCase.TESTMAP_PROJECT)
public class SQLServerSnifferTest extends ServerCase {

    @Inject
    private ServerCaseDataSourceFactory dataSourceFactory;

    @Inject
    private UnitDbAdapter accessStackAdapter;
    
    @Inject
    private AdhocObjectFactory objectFactory;

    public void testCreateAdapter() throws Exception {

        SQLServerSniffer sniffer = new SQLServerSniffer(objectFactory);

        DbAdapter adapter = null;
        Connection c = dataSourceFactory.getSharedDataSource().getConnection();

        try {
            adapter = sniffer.createAdapter(c.getMetaData());
        }
        finally {
            try {
                c.close();
            }
            catch (SQLException e) {

            }
        }

        if (accessStackAdapter instanceof SQLServerUnitDbAdapter) {
            assertNotNull(adapter);
        }
        else {
            assertNull(adapter);
        }
    }
}
